cordova.define("cordova-plugin-hx.hx", function(require, exports, module) {


var argscheck = require('cordova/argscheck'),
    exec = require('cordova/exec');


var hxExport = {};

hxExport.hideNavigationBar = function(successCallback, errorCallback) {
    exec(successCallback, errorCallback, "hx", "hideNavigationBar", []);
};

hxExport.showNavigationBar = function(successCallback, errorCallback){
   exec(successCallback, errorCallback, "hx", "showNavigationBar", []);
};

/**
获取位置信息
delegate为0： 位置信息返回
successCallback {'latitude':'23.444','longitude':'113.566','label':'长沙市雨花区万家丽路'}
errorCallback  string 失败原因

delegate为1：定位成功后由手机端直接打开地图
successCallback没有返回值
errorCallback返回值 String 失败原因
*/
hxExport.getCurrentPosition = function(successCallback, errorCallback , options){
 options = options || {};
 var getValue = argscheck.getValue;
 var delegate = getValue(options.delegate , 0);
 var win = function() {
 	 exec(successCallback, errorCallback, "hx", "getCurrentPosition", [delegate]);
 };
 var fail = function() {
 	if (errorCallback) {
 		errorCallback(new PositionError (PositionError.PERMISSION_DENIED, 'Illegal Access'));
 	}
 };
 exec(win, fail, "Geolocation", "getPermission", []);
};

/**
根据经纬度打开地图位置
successCallback没有返回值
errorCallback返回值 String 失败原因
*/
hxExport.openLocalMap = function(successCallback, errorCallback , options){
 options = options || {};
 var getValue = argscheck.getValue;
 var longitude = getValue(options.longitude, 0.0);
 var latitude = getValue(options.latitude , 0.0)
 exec(successCallback, errorCallback, "hx", "openLocalMap", [longitude,latitude]);
};

/**
获取用户UID
successCallback返回值 string 用户id
errorCallback返回值  string 失败原因
*/
hxExport.getUserid = function(successCallback, errorCallback ){
 exec(successCallback, errorCallback , "hx", "getUserid", []);
};

/**
获取用户信息
successCallback返回值 {'userid':'xiaoyang', 'username':'肖扬' ,'unitcode':990122'','unitname':'卓信智恒'}
errorCallback返回值  string 失败原因
*/
hxExport.getUserInfo = function(successCallback, errorCallback ){
 exec(successCallback, errorCallback , "hx", "getUserInfo", []);
};

/**
获取二维码
delegate为0：二维码结果返回
successCallback返回值 string 二维码结果
errorCallback返回值  string 失败原因

delegate为1：二维码结果直接由手机端处理
successCallback没有返回值
errorCallback返回值 String 失败原因
*/
hxExport.getQrcode = function(successCallback, errorCallback , options){
options = options || {};
 var getValue = argscheck.getValue;
 var delegate = getValue(options.delegate , 0);
 exec(successCallback, errorCallback , "hx", "getQrcode", [delegate]);
}

/**
设置手机摇一摇监听
successCallback没有返回值
errorCallback返回值 String 失败原因
*/
hxExport.setShakeListen = function(successCallback, errorCallback ){
 exec(successCallback, errorCallback , "hx", "setShakeListen" ,[]);
};

/**
转发命令到桌面端
successCallback没有返回值
errorCallback返回值 {'code':'451','message':'用户不在线'}
*/
hxExport.transCommandToCportal = function(successCallback, errorCallback , options){
 options = options || {};
 var getValue = argscheck.getValue;
 var title = getValue(options.title , '');
 var url = getValue(options.url , '');
 var contenttype = getValue(options.contenttype , '');
 exec(successCallback, errorCallback, "hx", "transCommandToCportal", [title,url , contenttype]);
};

/**
注册导航栏
successCallback没有返回值
errorCallback返回值 string 失败原因
*/
hxExport.registerMoreOpt = function(successCallback, errorCallback , options){
 options = options || {};
 var getValue = argscheck.getValue;
 var id = getValue(options.id , '');
 var name = getValue(options.name , '');
 var type = getValue(options.type , '');
 var link = getValue(options.link , '');
 exec(successCallback, errorCallback, "hx", "registerMoreOpt" ,[id , name , type , link]);
}

/**
取消注册导航栏
successCallback没有返回值
errorCallback返回值 string 失败原因
*/
hxExport.clearRegisterMoreOpt = function(successCallback, errorCallback ){
 exec(successCallback, errorCallback, "hx", "clearRegisterMoreOpt" ,[]);
}

/**
关闭当前窗口
*/
hxExport.closeCurrentWindow = function(successCallback, errorCallback){
 exec(successCallback, errorCallback, "hx", "closeCurrentWindow" ,[]);
}

module.exports = hxExport;

});
